# Migration

This submodule provides scripts for creating and reading vector migration input files that are directly ingested by 
EMOD for determining how individuals migrate between nodes over time during a simulation. Going forward, all reading 
and writing of these migration control files should be done via this submodule.

The script files convert from human-readable files (txt, json, csv) to binary migration files. Please see documentation
for more details. 


